const Errorhandler = require("./utils/Errorhandler");
const sendToken = require("./utils/jwt");

exports.registerUser = async (req, res, next, Model, Body) => {
  try {
    const user = await Model.create(Body);
    await user.save({ validateBeforeSave: false });
    sendToken(user, 201, res, "User Registration Success");
  } catch (error) {
    if (error.name === "ValidationError") {
      const validationErrors = Object.values(error.errors).map(
        (value) => value.message
      );
      next(new Errorhandler(validationErrors.join(", "), 500));
    } else {
      next(
        new Errorhandler(
          `Sorry, your request could not be completed ${error}`,
          500
        )
      );
    }
  }
};

exports.loginUser =async (req, res, next, Model)=> {
  try {
    const { email, password } = req.body;
    if (!email || !password) {
      return next(new Errorhandler("please enter email and password", 400));
    }
    // finding in db
    const user = await Model.findOne({ email }).select("+password");
    if (!user) {
      return next(new Errorhandler(" User Not Found", 401));
    }
    if (!(await user.isValidPassword(password))) {
      return next(new Errorhandler("email and password incorrect", 401));
    }

      sendToken(user, 201, res,"Login SuccessFull");
    
  } catch (error) {
    return next(new Errorhandler(error, 500));
  }
}
exports.logoutUser =(req, res, next) =>{
    try {
        res.cookie('token', null, {
            expires: new Date(Date.now()),
            httpOnly: true
        })
            .status(200)
            .json({
                success: true,
                message: 'LoggedOut'
            })
    } catch (error) {
        next(new Errorhandler(`sorry Your request could not be completed`))
    }


}